@@ -4,7 +4,10 @@ from PyQt4 import QtCore, QtGui
 from qtGUI.qtUImain import Ui_MainWindow
 from qtGUI.aboutDialog import Ui_aboutDialog
 from qtGUI.instrumentDialog import Ui_instrumentDialog
+from qtGUI.progressionDialog import Ui_progressionDialog
+from qtGUI.blockDialog import Ui_blockDialog
 from mingus.containers.Instrument import MidiInstrument
+from mingus.core import chords
 from sys import argv
 from os import path
 import Musicians
@@ -12,7 +15,7 @@ import Musicians
 import Options
 from mingus.core import diatonic
 
-APP_NAME = "pyImproviser"
+APP_NAME = "qtImproviser"
 APP_VERSION = "0.7"
 
 class OptionClass:
@@ -24,7 +27,6 @@ class OptionClass:
 	no_fluidsynth=False
 	verbose=True
 	meter = (4,4)
-	pass
 
 class InstrumentDialog(QtGui.QDialog):
 
@@ -70,7 +72,7 @@ class InstrumentDialog(QtGui.QDialog):
 		if not drum:
 			res += "midi_instr:%d " % (self.ui.midi.currentIndex())
 		res += "start:%d " % self.ui.stepstart.value()
-		res += "chance:%d " % (self.ui.chance.value())
+		res += "chance:%f " % (self.ui.chance.value())
 		if self.ui.step.value() != 0:
 			res += "step:%d " % self.ui.step.value()
 		if self.ui.stepend.value() != -1:
@@ -135,6 +137,43 @@ class InstrumentDialog(QtGui.QDialog):
 				return x
 		return -1
 
+class ProgressionDialog(QtGui.QDialog):
+
+	def __init__(self, item):
+		QtGui.QDialog.__init__(self)
+		self.item = item
+		self.ui = Ui_progressionDialog()
+		self.ui.setupUi(self)
+		self.setup()
+
+	def setup(self):
+		self.ui.accidentals.addItem("")
+		for x in range(1, 3):
+			self.ui.accidentals.addItem("b" * x)
+		for x in range(1, 3):
+			self.ui.accidentals.addItem("#" * x)
+
+		for x in ["I", "II", "III", "IV", "V", "VI", "VII"]:
+			self.ui.romannumeral.addItem(x)
+
+		for x in chords.chord_shorthand.keys():
+			self.ui.chordsuffix.addItem(x)
+
+		for x in ["1/4", "1/2", "3/4", "1", "2", "4"]:
+			self.ui.bars.addItem(x)
+
+class BlockDialog(QtGui.QDialog):
+
+	def __init__(self, item):
+		QtGui.QDialog.__init__(self)
+		self.item = item
+		self.ui = Ui_blockDialog()
+		self.ui.setupUi(self)
+		self.setup()
+
+	def setup(self):
+		pass
+
 class ImproviserMainWindow(QtGui.QMainWindow):
 
 	lastfile = ""
@@ -155,7 +194,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		p = "Untitled.imp"
 		if self.lastfile != "":
 			p = self.lastfile
-		self.setWindowTitle("%s - %s" % (APP_NAME, p))
+		self.setWindowTitle("%s %s - %s" % (APP_NAME, APP_VERSION, p))
 
 
 	def fill_combos(self):
@@ -212,9 +251,15 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.connect(self.ui.clearinstruments,
 			QtCore.SIGNAL("clicked()"),
 			self.ui.instruments.clear)
+		self.connect(self.ui.editblock,
+			QtCore.SIGNAL("clicked()"),
+			self.edit_block)
 		self.connect(self.ui.editinstrument,
 			QtCore.SIGNAL("clicked()"),
 			self.edit_instrument)
+		self.connect(self.ui.editprogression,
+			QtCore.SIGNAL("clicked()"),
+			self.edit_progression)
 		self.connect(self.ui.removeprogression,
 			QtCore.SIGNAL("clicked()"),
 			self.remove_progression)
@@ -272,6 +317,14 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		if i >= 0:
 			self.ui.instruments.takeItem(i)
 
+	def edit_block(self):
+		cur = self.ui.blocks.item(self.ui.blocks.currentRow())
+		if cur is None:
+			return
+		b = BlockDialog(self.ui.blocks.currentItem())
+		b.show()
+		b.exec_()
+
 	def edit_instrument(self):
 		cur = self.ui.instruments.item(self.ui.instruments.currentRow())
 		if cur is None:
@@ -281,6 +334,15 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		i.show()
 		i.exec_()
 
+	def edit_progression(self):
+		cur = self.ui.progressions.item(self.ui.progressions.currentRow())
+		if cur is None:
+			return
+		p = ProgressionDialog(self.ui.progressions.currentItem())
+		p.show()
+		p.exec_()
+
+
 	def get_file_name(self, name, n = 0):
 		if n == 0:
 			midi = name + ".mid"
